Lua_PeakDuelRolePanel = class("Lua_PeakDuelRolePanel", Lua_DisplayObject)
function Lua_PeakDuelRolePanel:ctor(p)
	self:superCall("ctor", p, "PeakDuelRolePanel_skin")
end

function Lua_PeakDuelRolePanel:buildShowItem()
	self:superCall("buildShowItem")

	self.leftPanel = Lua_HeroGridViewPanel.new(self.content)
	self.leftPanel:setLocation(-210, 11.5, 0)
	self.leftPanel:setLayout(1, 0)
	self.leftPanel:setGridCell(70, 70, Lua_PeakDuelRoleHeroGridItem)
	self.leftPanel:setCanClick(true)

	self.rightPanel = Lua_HeroGridViewPanel.new(self.content)
	self.rightPanel:setLocation(210, 11.5, 0)
	self.rightPanel:setLayout(1, 0)
	self.rightPanel:setGridCell(70, 70, Lua_PeakDuelRoleHeroGridItem)
	self.rightPanel:setCanClick(true)

	self.leftForce = Lua_NumberImage.new(self.content)
	self.leftForce:setLocation(-299, -150, 0)
	self.leftForce.pivot = 1
	self.leftForce.numOffsetX = -3
	self.leftForce.numAtlas = "number"
	self.leftForce.preStr = "xui_zl1_number_0"

	self.rightForce = Lua_NumberImage.new(self.content)
	self.rightForce:setLocation(337, -150, 0)
	self.rightForce.pivot = -1
	self.rightForce.numOffsetX = -3
	self.rightForce.numAtlas = "number"
	self.rightForce.preStr = "xui_zl1_number_0"

	self.checkFight:addClickFuntion(self, self.onCheckFight)
end

function Lua_PeakDuelRolePanel:dispose()
	self:stopTimer()
	if self.leftPanel then
		self.leftPanel:dispose()
		self.leftPanel = nil
	end
	if self.rightPanel then
		self.rightPanel:dispose()
		self.rightPanel = nil
	end
	if self.leftForce then
		self.leftForce:dispose()
		self.leftForce = nil
	end
	if self.rightForce then
		self.rightForce:dispose()
		self.rightForce = nil
	end
	self.owner = nil
	self.callBack = nil
	self:superCall("dispose")
end

function Lua_PeakDuelRolePanel:setCallBack(owner, callBack)
	self.owner = owner
	self.callBack = callBack
end

function Lua_PeakDuelRolePanel:setRoleInfo(att_role, def_role, winId, lineupIdx)
	if att_role == nil or tonumber(att_role.show_role.id) <= 0 then
		self.left_name.text = nil
		self.left_integral.text = nil
		self.icon_1:setEnable(false)
		self.icon_3:setEnable(false)
		self.leftPanel:setDataByProto(nil)
		self.leftForce.num = nil
	else
		local role = att_role.show_role
		self.left_name.text = LanUtil.formateStr(10051, role.server_prev, role.name)
		self.left_integral.text = att_role.score
		
		local info = self:getLineupInfo(att_role.lineup, lineupIdx)
		if info then
			self.leftPanel:setDataByProto(info.hero_list)
			self.leftForce.num = info.force
		else
			self.leftPanel:setDataByProto(nil)
			self.leftForce.num = nil
		end

		self.icon_1:setEnable(true)

		local config = DataCenter.peakDuelUtil:getSegmentInfoByid(att_role.segment_lvl)
		self.icon_3:setEnable(true)
		self.icon_3:setAltas("peak_duel_altas", config.icon)
	end

	if def_role == nil or tonumber(def_role.show_role.id) <= 0 then
		self.right_name.text = nil
		self.right_integral.text = nil
		self.icon_2:setEnable(false)
		self.icon_4:setEnable(false)
		self.rightPanel:setDataByProto(nil)
		self.rightForce.num = nil
	else
		local role = def_role.show_role
		self.right_name.text = LanUtil.formateStr(10051, role.server_prev, role.name)
		self.right_integral.text = def_role.score
		
		local info = self:getLineupInfo(def_role.lineup, lineupIdx)
		if info then
			self.rightPanel:setDataByProto(info.hero_list)
			self.rightForce.num = info.force
		else
			self.rightPanel:setDataByProto(nil)
			self.rightForce.num = nil
		end

		self.icon_2:setEnable(true)
		self.icon_2:setLocation(337 - self.rightForce.totalWidth - 20, -150, 0)

		local config = DataCenter.peakDuelUtil:getSegmentInfoByid(def_role.segment_lvl)
		self.icon_4:setEnable(true)
		self.icon_4:setAltas("peak_duel_altas", config.icon)
	end

	if winId == nil or winId == 0 then
		self.left_result:setEnable(false)
		self.right_result:setEnable(false)
	else
		self.left_result:setEnable(true)
		self.right_result:setEnable(true)
		if winId == 1 then
			self.left_result:setAltas("common_altas_4", "xui_jys_label_1")
			self.right_result:setAltas("common_altas_4", "xui_jys_label_2")
		else
			self.left_result:setAltas("common_altas_4", "xui_jys_label_2")
			self.right_result:setAltas("common_altas_4", "xui_jys_label_1")
		end
		self.left_result:resetSize()
		self.right_result:resetSize()
	end	
end

function Lua_PeakDuelRolePanel:getLineupInfo(lineup, lineupIdx)
	if lineup then
		for i = 1, #lineup do
			if lineup[i].index == lineupIdx then
				return lineup[i]
			end
		end
	end
	return nil
end

function Lua_PeakDuelRolePanel:setStageInfo(info, recordId)
	self.scheduleText.text = nil
	local serverTime = DataCenter.roleData.serverTime
	if serverTime < tonumber(info.interaction_end_tick) then -- 互动阶段
		self.stageType = 1
		self.checkFight:setEnable(false)
		self.stageBg:setEnable(true)
		self.stageText:setEnable(true)
		self.stageText:setLangValue(202972)
		self.timeText:setEnable(true)
		self.endTime = tonumber(info.interaction_end_tick)
		self:startTimer()
		self:onTimer()
	elseif serverTime < tonumber(info.match_end_tick) then -- 比赛阶段
		self.checkFight:setEnable(true)
		self.stageBg:setEnable(true)
		self.stageText:setEnable(true)
		self.stageText:setLangValue(202973)
		self.timeText:setEnable(true)
		self.endTime = tonumber(info.match_end_tick)
		self:startTimer()
		self:onTimer()
	elseif serverTime < tonumber(info.next_start_tick) then -- 结算阶段
		self.checkFight:setEnable(true)
		self.stageBg:setEnable(true)
		self.stageText:setEnable(true)
		self.stageText:setLangValue(202974)
		self.timeText:setEnable(true)
		self.endTime = tonumber(info.next_start_tick)
		self:startTimer()
		self:onTimer()
	else
		self:stopTimer()
		self.checkFight:setEnable(false)
		self.stageBg:setEnable(false)
		self.stageText:setEnable(false)
		self.timeText:setEnable(false)
	end
	self.recordId = recordId
end

function Lua_PeakDuelRolePanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true
		self:addTimer("GUESS_TIMER", 1, self, self.onTimer, nil, -1)
	end
end

function Lua_PeakDuelRolePanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false
		self:removeTimer(self, self.onTimer)
	end
end

function Lua_PeakDuelRolePanel:onTimer()
	local second = self.endTime - DataCenter.roleData.serverTime
	if second > 0 then
		self.timeText.text = Lua_TimeTransform.transSeconds6(second)
	else
		self:stopTimer()
		self.checkFight:setEnable(false)
		self.stageBg:setEnable(false)
		self.stageText:setEnable(false)
		self.timeText:setEnable(false)
		if self.owner and self.callBack then
			self.callBack(self.owner)
		end
	end
end

function Lua_PeakDuelRolePanel:onCheckFight(go)
	if self.recordId == nil then
		return
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.recordId, 0, "", 0, 3)
end










Lua_PeakDuelRoleHeroGridItem = class("Lua_PeakDuelRoleHeroGridItem", Lua_HeroGridViewItem)
function Lua_PeakDuelRoleHeroGridItem:ctor(p)
	self:superCall("ctor", p)
end

function Lua_PeakDuelRoleHeroGridItem:buildShowItem()
	self:superCall("buildShowItem")
	self.bg:setAltas("common_altas_4", "xui_jys_widget_7")
	self.bg:SetDimensions(118, 118)
	self.bg:setScale(0.56, 0.56, 1)
end

function Lua_PeakDuelRoleHeroGridItem:setData(dataType, data)
	self:superCall("setData", dataType, data)
	if self.itemIcon then
		self.itemIcon:setScale(0.56, 0.56, 1)
	end
end